/*
 * General definitions
 */
#define     OK          0
#define     ERROR       -1
#define     NG          100
#define     ON          1
#define     OFF         0
#define     YES         1
#define     NO          0
#define     TRUE        1
#define     FALSE       0
#define     STANDBY     2

/*
 * ASCII definitions
 */
#define     SOH         0x01
#define     STX         0x02
#define     ETX         0x03
#define     EOT         0x04
#define     ENQ         0x05
#define     ACK         0x06
#define     BEL         0x07
#define     BS          0x08
#define     HT          0x09
#define     LF          0x0A
#define     VT          0x0B
#define     FF          0x0C
#define     CR          0x0D
#define     SO          0x0E
#define     SI          0x0F
#define     DLE         0x10
#define     DC1         0x11
#define     DC2         0x12
#define     DC3         0x13
#define     DC4         0x14
#define     NAK         0x15
#define     SYN         0x16
#define     ETB         0x17
#define     CAN         0x18
#define     EM          0x19
#define     SUB         0x1A
#define     ESC         0x1B
#define     FS          0x1C
#define     GS          0x1D
#define     RS          0x1E
#define     US          0x1F
#define     SP          0x20
#define     DEL         0x7F

/*
 * Keyboard definition, some models do not support all keys.
 */
#define TRIGGER_KEY     0x80
#define UP_KEY          0x81
#define DOWN_KEY        0x82
#define Q1_KEY          UP_KEY
#define Q2_KEY          DOWN_KEY
#define	ENT_KEY			0x83
#define CLR_KEY			0x84
#define BS_KEY			0x85
#define LEFT_KEY		0x86
#define RIGHT_KEY		0x87
#define SHIFT_KEY		0x88

#define IS_BREAK_CODE(x)	(((x) <= 0x20) ? TRUE : FALSE)
#define SET_BREAK_FLAG(x)	((x) - 0x20)
#define CLEAR_BREAK_FLAG(x)	((x) + 0x20)

/*
 * structures for RTC
 */
struct time
{   unsigned char ti_hour;
    unsigned char ti_min;
    unsigned char ti_sec;
};

struct date
{   unsigned int  da_year;
    unsigned char da_day;
    unsigned char da_mon;
};

/*
 * structures for the readbarcode function
 */
struct barcode
{   char    *text;
    int     length;
    int     id;
    int     min;
    int     max;
};

/*
 * Constants for id member
 */
#define JAN13           0x01
#define EAN13           0x02
#define ISBN			EAN13
#define ISSN			EAN13
#define ISMN			EAN13
#define UPCA            0x03
#define JAN8            0x04
#define EAN8            0x05
#define UPCE            0x06
#define UPCE1           0x07
#define CODE39          0x09
#define CODABAR         0x0A
#define NW7             CODABAR
#define D2OF5           0x0B                    // industrial 2 of 5
#define I2OF5           0x0C                    // interleaved 2 of 5
#define CODE93          0x0D
#define CODE128         0x0E
#define MSI_PLESSEY     0x0F
#define IATA            0x10
#define UK_PLESSEY      0x11
#define TELEPEN         0x12
#define M2OF5           0x13
#define CHINPOST        0x14
#define NW7_ABC         0x15
#define NW7_CX          0x16
#define SCODE           0x17
#define LAETUS          0x18
#define TRIOPTIC        LAETUS
#define C39_FA          0x19                    // Full ascii
#define C39_IT          0x1A                    // Italian pharma code
#define EAN128          0x1B

#define RSS_14          0x1C
#define RSS_LIMITED     0x1D
#define RSS_EXPANDED    0x1E

#define PDF417          0x1F
#define CCC_COMPOSITE   0x20

#define MICRO_PDF417    0x21
#define CCA_COMPOSITE   0x22
#define CCB_COMPOSITE   0x23

#define CODE11          0x24

#define EAN128_CCC      0x25                    // EAN-128 with CC-C composite
#define CODE3OF5        0x26                    // Code 3 of 5 A.K.A. Korean Postal Code

/*** ADD ON +2 ***/
#define ADD_ON_2        0x40
#define JAN13_2         0x41
#define EAN13_2         0x42
#define UPCA_2          0x43
#define JAN8_2          0x44
#define EAN8_2          0x45
#define UPCE_2          0x46
#define UPCE1_2         0x47
#define CODE128_2       0x4E                    // the same group CODE-128

/*** ADD ON +5 ***/
#define ADD_ON_5        0x80
#define JAN13_5         0x81
#define EAN13_5         0x82
#define UPCA_5          0x83
#define JAN8_5          0x84
#define EAN8_5          0x85
#define UPCE_5          0x86
#define UPCE1_5         0x87
#define CODE128_5       0x8E                    // the same group CODE-128

#define ADD_ON_MASK		0xC0
#define MENU_CODE       0xF0                    // OSE Code-39 Menu label
#define MENU_CODE_PDF   0xF1                    // OSE (u)PDF417 Menu label
#define MENU_CODE_C128  0xF2                    // OSE Code-128 Menu label

/*
 * Constants for file system
 */

#define D_NAME               8
#define D_EXT                3

struct ffblk
{   char name[D_NAME+1];
    char ext[D_EXT+1];
    long filesize;
    char search_name[D_NAME+1];
    char search_ext[D_EXT+1];
    int slot;
};

#ifndef O_RDONLY
#define O_RDONLY        0x01    /*   open for read only          */
#define O_WRONLY        0x02    /*   open for write only         */
#define O_RDWR          0x03    /*   open for read and write     */
#define O_APPEND        0x08    /*   writes performed at EOF     */
#define O_CREAT         0x10    /*   create file                 */
#define O_TRUNC         0x20    /*   truncate file               */
#define O_FORM          0x40    /*   text file                   */
#define O_BINARY        0x80    /*   binary file                 */
#endif

/*
 * Additional (Non ANSI) standard streams
 */
#define stdaux  3
#define stdprn  4

/*
 * Constants for function 'GoodRead'
 */
#define RED             1
#define GREEN           2
#define ORANGE          RED|GREEN
#define RED_FLASH       4
#define GREEN_FLASH     8
#define ORANGE_FLASH    RED_FLASH|GREEN_FLASH
#define BLUE            0x10
#define AQUA            BLUE|GREEN
#define PURPLE          BLUE|RED
#define WHITE           RED|GREEN|BLUE
#define BLUE_FLASH      0x40


/*
 * Constants for the ischarging function
 */
#define CHG_OFF			0x00
#define CHG_ON			0x01
#define SUP_CHG			0x02
#define CHG_COMPLETE	0x03
#define WAIT_RECHG		0x04
#define RECHG_ON		0x05
#define CHG_TIME_OVER	0x06
#define OUT_CHG_TEMP	0x07

/*
 * Constant for backlight and flipscreen
 */
#define AUTO		2

/*
 * Constant for flipscreen
 */
#define TOGGLE		3

/*
 * Constants for cursor
 */
#define BLINKING    2
#define AUTOWRAP    3
#define NOWRAP      4

/*
 * Screen resolution
 */
#define DISP_WIDTH  112
#define DISP_HEIGHT 64

/*
 * Constants for ScannerPower
 */
#define TRIGGER     2
#define SINGLE      3
#define MULTIPLE    4
#define CONTINUOUS  5

/*
 * Constants for redundancy
 */
#define DIFFERENT       1
#define SAME            2
#define SUFFICIENT      3
#define NOT_SUFFICIENT  4

/*
 * definitions for sound volume level
 */
#define VOFF        0
#define VLOW        1
#define VSTANDARD   8
#define VMEDIUM     32
#define VHIGH       127

/*
 * definitions for sound tone duration
 */
#define TCLICK      1
#define TSHORT      3
#define TSTANDARD   5
#define TLONG       10
#define TVLONG      20


/*
 * definitions for sound tone
 */
#define SPAUSE      1
#define SERROR      100
#define SLOW        1000
#define SMEDIUM     2500
#define SHIGH       3500

/*
 * definitions for xmodem receive
 */
#define XMR_OK           0
#define XMR_CREATE_ERR   1
#define XMR_POLL_ERR     2
#define XMR_ABORT_ERR    3
#define XMR_BLOCK_ERR    4
#define XMR_CRC_ERR      5
#define XMR_CHECKSUM_ERR 6
#define XMR_WRITE_ERR    7
#define XMR_RESPONSE_ERR 8
#define XMR_MEM_ERR      9

/*
 * definitions for xmodem transmit
 */
#define XMT_OK           0
#define XMT_OPEN_ERR     1
#define XMT_RESPONSE_ERR 2
#define XMT_POLL_ERR     3
#define XMT_READ_ERR     4
#define XMT_ACK_ERR1     5
#define XMT_ACK_ERR2     6
#define XMT_MEM_ERR      7

/*
 * (old) definitions for neto, do not use for new applications
 */
#define NETO_OK           0
#define NETO_KBHIT        1
#define NETO_RESPONSE_ERR 2
#define NETO_KILLED       3
#define NETO_OPEN_ERR     4
#define NETO_WRITE_ERR    5
#define NETO_READ_ERR     6
#define NETO_MEM_ERR      7

/*
 * (new) definitions for neto
 */
#define ERR_USER_BREAK      -3
#define ERR_EOT_HOST        -5
#define ERR_HOST_REQ        -6
#define ERR_OPEN_FILE       -8
#define ERR_WRITE_FILE      -9
#define ERR_READ_FILE       -10
#define ERR_OUT_SYNC        -12
#define ERR_ALOC_MEM        -13

/*
 * Constants for setfont
 */
#define SMALL_FONT      0x01
#define LARGE_FONT      0x02
#define USER_FONT       0x03

#define KANJI12_FONT    0x04
#define KANJI16_FONT    0x05
#define FILE_FONT       0x06

#define MEDIUM_FONT     0x07
#define TINY_FONT       0x08

/*
 * Constants for autopowerdown
 */
#define RESET      0x02
#define NOW        0x03
#define SUSPEND    0x06
#define RESUME     0x07

/*
 * Constatnts for the com_idle function
 */
#define PARK					1
#define EXIT_PARK				2
#define SNIFF					3
#define EXIT_SNIFF				4
#define HOLD					5
#define	EXIT_HOLD_CHECK			6


/*
 * Constants for comopen
 */
#define     COM0        0
#define     COM1        1      // IrDA adapter
#define     COM2        2      // Cradle
#define     COM3        3
#define     COM4        4
#define     COM5        5
#define     COM6        6

#define INVALID_S2_FILE     -1 // File is not an S2 file, or it contains errors
#define INVALID_TERMINAL    -2 // The file is for a different terminal
#define NEED_HIGHER_OS      -3 // The application needs a higher OS.
#define NO_FILE             -4 // When the file does not exists

typedef struct device_info
{
	char bd_address[13];
	char name[16];
}device_info;

/*
 *  function prototypes
 */
int checktime(struct time *timep);
int checkdate(struct date *datep);
unsigned batteryvoltage(void);
unsigned long coreleft(void);
void delay(int time);
int getcom(int timeout);
void gettime(struct time *timep);
void getdate(struct date *datep);
int settime(struct time *timep);
int setdate(struct date *datep);
void SetAlarm(struct time *timep, unsigned short onoff);
void goodreadled(int on_off, int time);
void idle(void);
unsigned int kbhit(void);
int putcom(int data);
int readbarcode(struct barcode *barcodep);
void resetkey(void);
void resetreceive(void);
void scannerpower(int mode, int time);
int scanneroff(void);
void sound(int time, int vol, ...);
int systemsetting(const char *options);
int xmodemtransmit(const char *filename);
int xmodemreceive(const char *filename);
void autopowerdown(int what, unsigned long time);
int findfirst(const char *fname,struct ffblk *ffblk);
int findnext(struct ffblk *ffblk);
void starttimer(unsigned int timevalue);
int endtimer(void);
int comopen (unsigned int com);
int comclose (unsigned int com);
long fsize(const char *filename);
int ischarging(void);
int open(char  *, int, int);
int chsize(int, long);
int close(int);
long tell(int);
long lseek(int,long,int);
int eof(int);
int read(int , char *, unsigned int );
int write(int, char *, unsigned int );
int neto_receive( char (*filename)[12 + 1], const char *term_id, int tkey, int ypos/*, int my_delay*/);
int neto_transmit( char (*filename)[12 + 1], int file_count, const char *term_id, int tkey, int ypos/*, int my_delay*/);
int timervalue(void);
int triggerpressed(void);
void version_os(char os[9]);
void version_rom(char rom[9]);
int neto_receive2( char (*filename)[12 + 1], const char *term_id, unsigned int timeout, int tkey, int ypos);
int neto_transmit2( char (*filename)[12 + 1], int file_count, const char *term_id, unsigned int timeout, int tkey, int ypos);
void *far_malloc (unsigned long nbytes);
int format(void);
void putstring(char *string);
int runapplfromfile(char *filename);
unsigned char isBuzzerOn(void);
void SuspendAutoPof(void);
void ResumeAutoPof(void);
void Download(int autodownload);

void drawline(int x1,int y1,int x2,int y2,int mode);
void setpixel(int x, int y, int state);
void showpicture(int x_offs, int y_offs, const unsigned char *ptr);
int wherex(void);
int wherey(void);
void gotoxy(int x, int y);
int contrast(int value);
void cursor(int mode);
int setfont(unsigned int type, unsigned char *font_ptr);
int savedisplay(char *filename);
int loaddisplay(char *filename);
void printsymbol(unsigned data);
int flipscreen(int mode);
void set_offset(int offset);
void getfontsize(unsigned int *height, unsigned int *width);
int powereddown(void);
unsigned int getterminalid(void);
void setterminalid(unsigned int id);
int eraseblock(unsigned blocknr);
void programword(unsigned data, unsigned* address);
void programbuffer(unsigned char *buffer, unsigned char *target_address, int len);
void backlight(short what, short time);

int com_idle(int mode, unsigned int arg);
unsigned char *GetBltAddress(void);
unsigned char *GetBltPin(void);
void SetBltAddress(const char *address);
void SetBltPin(const char *pincode);

unsigned long GetSystemTime(void);
void SetSystemTime(unsigned long time);
unsigned int GetTickCount(void);

int blt_is_connected( void );
unsigned char *GetBltLocalName( void );
void SetBltLocalName(const char *localname );
int blt_discovery( device_info *dev_inf, int abortkey );
void blt_unpair(void);

// OPL9713/DX00100 functions
void ClearGpsReceiver(void);
void InitGps(void);
void GpsPower(unsigned short onoff);
int ReadGps(void);
void WriteGps(unsigned char data);

